@@ -1,6 +1,6 @@
 # flake8: noqa
 
-logo = """
+logo = r"""
  ____  ____  __    ___       ___  _  _  ____  ___  __ _ 
 / ___)(_  _)/ _\  / __)___  / __)/ )( \(  __)/ __)(  / )
 \___ \  )( /    \( (__(___)( (__ ) __ ( ) _)( (__  )  ( 
